@@ -3,9 +3,11 @@ from strify.replacing.replacement_data import FuncReplacementData, AttrNameRepla
 
 
 class Replacement:
-    def __init__(self,
-                 replacement_info: Union[FuncReplacementData, AttrNameReplacementData],
-                 preprocessing_func: Callable):
+    def __init__(
+            self,
+            replacement_info: Union[FuncReplacementData, AttrNameReplacementData],
+            preprocessing_func: Callable
+    ):
         self.info = replacement_info
         self.preprocessing_func = preprocessing_func
 
