@@ -14,11 +14,11 @@ class ReplacementData(ABC):
 
     @property
     @abstractmethod
-    def attr_name(self) -> str:
+    def marker_attr(self) -> str:
         pass
 
     def get(self, instance) -> Any:
-        attr = getattr(instance, self.attr_name)
+        attr = getattr(instance, self.marker_attr)
 
         if inspect.ismethod(attr):
             if gets_only_one_parameter(attr):
